package com.aucma.dms.mapper;

//import com.aucma.dms.domain.DmsBaseDeviceFiles;

import com.aucma.dms.domain.DmsBaseDeviceFiles;

import java.util.List;

/**
 * 设备档案信息Mapper接口
 * 
 * @author xins
 * @date 2024-01-09
 */
public interface DmsBaseDeviceFilesMapper 
{
    /**
     * 查询设备档案信息
     * 
     * @param deviceFilesId 设备档案信息主键
     * @return 设备档案信息
     */
    public DmsBaseDeviceFiles selectDmsBaseDeviceFilesByDeviceFilesId(Long deviceFilesId);

    /**
     * 查询设备档案信息列表
     * 
     * @param dmsBaseDeviceFiles 设备档案信息
     * @return 设备档案信息集合
     */
    public List<DmsBaseDeviceFiles> selectDmsBaseDeviceFilesList(DmsBaseDeviceFiles dmsBaseDeviceFiles);

    /**
     * 新增设备档案信息
     * 
     * @param dmsBaseDeviceFiles 设备档案信息
     * @return 结果
     */
    public int insertDmsBaseDeviceFiles(DmsBaseDeviceFiles dmsBaseDeviceFiles);

    /**
     * 修改设备档案信息
     * 
     * @param dmsBaseDeviceFiles 设备档案信息
     * @return 结果
     */
    public int updateDmsBaseDeviceFiles(DmsBaseDeviceFiles dmsBaseDeviceFiles);

    /**
     * 删除设备档案信息
     * 
     * @param deviceFilesId 设备档案信息主键
     * @return 结果
     */
    public int deleteDmsBaseDeviceFilesByDeviceFilesId(Long deviceFilesId);

    /**
     * 批量删除设备档案信息
     * 
     * @param deviceFilesIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseDeviceFilesByDeviceFilesIds(Long[] deviceFilesIds);
}
