package com.aucma.dms.controller;

//import com.hw.common.core.utils.poi.ExcelUtil;
//import com.hw.common.core.web.controller.BaseController;
//import com.hw.common.core.web.domain.AjaxResult;
//import com.hw.common.core.web.page.TableDataInfo;
//import com.hw.common.log.annotation.Log;
//import com.hw.common.log.enums.BusinessType;
//import com.hw.common.security.annotation.RequiresPermissions;
//import com.aucma.dms.domain.DmsBaseDeviceFiles;
//import com.aucma.dms.service.IDmsBaseDeviceFilesService;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseDeviceFiles;
import com.aucma.dms.service.IDmsBaseDeviceFilesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 设备档案信息Controller
 *
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/dms/dmsFiles")
public class DmsBaseDeviceFilesController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceFilesService dmsBaseDeviceFilesService;


    /**
     * 查询设备档案信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        startPage();
        List<DmsBaseDeviceFiles> list = dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesList(dmsBaseDeviceFiles);
        return getDataTable(list);
    }

    /**
     * 导出设备档案信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:export')" )
    //@Log(title = "设备档案信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        List<DmsBaseDeviceFiles> list = dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesList(dmsBaseDeviceFiles);
        ExcelUtil<DmsBaseDeviceFiles> util = new ExcelUtil<DmsBaseDeviceFiles>(DmsBaseDeviceFiles.class);
        util.exportExcel(response, list, "设备档案信息数据");
    }

    /**
     * 获取设备档案信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:query')" )
    @GetMapping(value = "/{deviceFilesId}")
    public AjaxResult getInfo(@PathVariable("deviceFilesId") Long deviceFilesId)
    {
        return success(dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesByDeviceFilesId(deviceFilesId));
    }

    /**
     * 新增设备档案信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:add')" )
    //@Log(title = "设备档案信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {

        return toAjax(dmsBaseDeviceFilesService.insertDmsBaseDeviceFiles(dmsBaseDeviceFiles));
    }

    /**
     * 修改设备档案信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:edit')" )
    //@Log(title = "设备档案信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        return toAjax(dmsBaseDeviceFilesService.updateDmsBaseDeviceFiles(dmsBaseDeviceFiles));
    }

    /**
     * 删除设备档案信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsFiles:remove')" )
    //@Log(title = "设备档案信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceFilesIds}")
    public AjaxResult remove(@PathVariable Long[] deviceFilesIds)
    {
        return toAjax(dmsBaseDeviceFilesService.deleteDmsBaseDeviceFilesByDeviceFilesIds(deviceFilesIds));
    }


}
